@@ -47,19 +47,19 @@ with requests.Session() as session:
 
         detail = [
             PayloadDetail(
-                LogLevel.info,
+                LogLevel.info.value,
                 sourceFilePath,
                 None,
                 None,
                 None,
                 None,
                 message,
-                LogLevel.info,
+                LogLevel.info.value,
                 __version__,
                 PayloadDetailMetadata(
                     sourceFilePath,
                     methodName,
-                    LogLevel.info,
+                    LogLevel.info.value,
                     message
                 ),
                 PayloadDetailSdk(
@@ -88,19 +88,19 @@ with requests.Session() as session:
 
         detail = [
             PayloadDetail(
-                LogLevel.error,
+                LogLevel.error.value,
                 sourceFilePath,
                 None,
                 None,
                 None,
                 None,
                 message,
-                LogLevel.error,
+                LogLevel.error.value,
                 __version__,
                 PayloadDetailMetadata(
                     sourceFilePath,
                     methodName,
-                    LogLevel.error,
+                    LogLevel.error.value,
                     message
                 ),
                 PayloadDetailSdk(
